# collect_informations_linkedin_scraper


## This package allow you to get informations about people who are interested about a given keyword and get it in json file

## HOW TO USE IT :
### first step : from linkedin_package.json_scrape or csv_scrape import webscrape
### then put your keyword in the input filed in the terminal , after that webscrape need an email and password and keyword like a parameter 
### and finally yyou can tell the function login() and collect_informations() to get the result 

